==> gammaray-3.1.0-2-riscv64.pkg.tar.zst: usr/lib/cmake/GammaRay/GammaRayTarget-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "gammaray_kitemmodels" for configuration "Release"
set_property(TARGET gammaray_kitemmodels APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_kitemmodels PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_kitemmodels-qt6_7-riscv64.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_kitemmodels-qt6_7-riscv64.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_kitemmodels )
list(APPEND _cmake_import_check_files_for_gammaray_kitemmodels "${_IMPORT_PREFIX}/lib/libgammaray_kitemmodels-qt6_7-riscv64.so.3.1.0" )

# Import target "gammaray_common" for configuration "Release"
set_property(TARGET gammaray_common APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_common PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gammaray_kitemmodels"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_common-qt6_7-riscv64.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_common-qt6_7-riscv64.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_common )
list(APPEND _cmake_import_check_files_for_gammaray_common "${_IMPORT_PREFIX}/lib/libgammaray_common-qt6_7-riscv64.so.3.1.0" )

# Import target "gammaray_core" for configuration "Release"
set_property(TARGET gammaray_core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_core PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gammaray_kitemmodels"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_core-qt6_7-riscv64.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_core-qt6_7-riscv64.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_core )
list(APPEND _cmake_import_check_files_for_gammaray_core "${_IMPORT_PREFIX}/lib/libgammaray_core-qt6_7-riscv64.so.3.1.0" )

# Import target "gammaray_probe" for configuration "Release"
set_property(TARGET gammaray_probe APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_probe PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_probe-qt6_7-riscv64.so"
  IMPORTED_SONAME_RELEASE "libgammaray_probe-qt6_7-riscv64.so"
  )

list(APPEND _cmake_import_check_targets gammaray_probe )
list(APPEND _cmake_import_check_files_for_gammaray_probe "${_IMPORT_PREFIX}/lib/libgammaray_probe-qt6_7-riscv64.so" )

# Import target "gammaray_launcher" for configuration "Release"
set_property(TARGET gammaray_launcher APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_launcher PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gammaray_common"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_launcher.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_launcher.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_launcher )
list(APPEND _cmake_import_check_files_for_gammaray_launcher "${_IMPORT_PREFIX}/lib/libgammaray_launcher.so.3.1.0" )

# Import target "gammaray_launcher_ui" for configuration "Release"
set_property(TARGET gammaray_launcher_ui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_launcher_ui PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gammaray_ui"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_launcher_ui.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_launcher_ui.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_launcher_ui )
list(APPEND _cmake_import_check_files_for_gammaray_launcher_ui "${_IMPORT_PREFIX}/lib/libgammaray_launcher_ui.so.3.1.0" )

# Import target "gammaray_kuserfeedback" for configuration "Release"
set_property(TARGET gammaray_kuserfeedback APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_kuserfeedback PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_kuserfeedback.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_kuserfeedback.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_kuserfeedback )
list(APPEND _cmake_import_check_files_for_gammaray_kuserfeedback "${_IMPORT_PREFIX}/lib/libgammaray_kuserfeedback.so.3.1.0" )

# Import target "gammaray_ui" for configuration "Release"
set_property(TARGET gammaray_ui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_ui PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gammaray_kitemmodels;KF6::SyntaxHighlighting"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_ui-qt6_7-riscv64.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_ui-qt6_7-riscv64.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_ui )
list(APPEND _cmake_import_check_files_for_gammaray_ui "${_IMPORT_PREFIX}/lib/libgammaray_ui-qt6_7-riscv64.so.3.1.0" )

# Import target "gammaray_client" for configuration "Release"
set_property(TARGET gammaray_client APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_client PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gammaray_ui;gammaray_common"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_client.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_client.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_client )
list(APPEND _cmake_import_check_files_for_gammaray_client "${_IMPORT_PREFIX}/lib/libgammaray_client.so.3.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> gammaray-3.1.0-3-riscv64.pkg.tar.zst: usr/lib/cmake/GammaRay/GammaRayTarget-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "gammaray_kitemmodels" for configuration "Release"
set_property(TARGET gammaray_kitemmodels APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_kitemmodels PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_kitemmodels-qt6_8-riscv64.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_kitemmodels-qt6_8-riscv64.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_kitemmodels )
list(APPEND _cmake_import_check_files_for_gammaray_kitemmodels "${_IMPORT_PREFIX}/lib/libgammaray_kitemmodels-qt6_8-riscv64.so.3.1.0" )

# Import target "gammaray_common" for configuration "Release"
set_property(TARGET gammaray_common APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_common PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Network;Qt6::Gui;gammaray_kitemmodels"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_common-qt6_8-riscv64.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_common-qt6_8-riscv64.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_common )
list(APPEND _cmake_import_check_files_for_gammaray_common "${_IMPORT_PREFIX}/lib/libgammaray_common-qt6_8-riscv64.so.3.1.0" )

# Import target "gammaray_core" for configuration "Release"
set_property(TARGET gammaray_core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_core PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gammaray_kitemmodels;Qt6::Gui;Qt6::Network"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_core-qt6_8-riscv64.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_core-qt6_8-riscv64.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_core )
list(APPEND _cmake_import_check_files_for_gammaray_core "${_IMPORT_PREFIX}/lib/libgammaray_core-qt6_8-riscv64.so.3.1.0" )

# Import target "gammaray_probe" for configuration "Release"
set_property(TARGET gammaray_probe APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_probe PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_probe-qt6_8-riscv64.so"
  IMPORTED_SONAME_RELEASE "libgammaray_probe-qt6_8-riscv64.so"
  )

list(APPEND _cmake_import_check_targets gammaray_probe )
list(APPEND _cmake_import_check_files_for_gammaray_probe "${_IMPORT_PREFIX}/lib/libgammaray_probe-qt6_8-riscv64.so" )

# Import target "gammaray_launcher" for configuration "Release"
set_property(TARGET gammaray_launcher APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_launcher PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gammaray_common;Qt6::Network;Qt6::Gui;Qt6::Widgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_launcher.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_launcher.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_launcher )
list(APPEND _cmake_import_check_files_for_gammaray_launcher "${_IMPORT_PREFIX}/lib/libgammaray_launcher.so.3.1.0" )

# Import target "gammaray_launcher_ui" for configuration "Release"
set_property(TARGET gammaray_launcher_ui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_launcher_ui PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Core;Qt6::Concurrent;Qt6::Gui;Qt6::Widgets;Qt6::Network;gammaray_ui"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_launcher_ui.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_launcher_ui.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_launcher_ui )
list(APPEND _cmake_import_check_files_for_gammaray_launcher_ui "${_IMPORT_PREFIX}/lib/libgammaray_launcher_ui.so.3.1.0" )

# Import target "gammaray_kuserfeedback" for configuration "Release"
set_property(TARGET gammaray_kuserfeedback APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_kuserfeedback PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Gui;Qt6::Network"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_kuserfeedback.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_kuserfeedback.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_kuserfeedback )
list(APPEND _cmake_import_check_files_for_gammaray_kuserfeedback "${_IMPORT_PREFIX}/lib/libgammaray_kuserfeedback.so.3.1.0" )

# Import target "gammaray_ui" for configuration "Release"
set_property(TARGET gammaray_ui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_ui PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gammaray_kitemmodels;KF6::SyntaxHighlighting"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_ui-qt6_8-riscv64.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_ui-qt6_8-riscv64.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_ui )
list(APPEND _cmake_import_check_files_for_gammaray_ui "${_IMPORT_PREFIX}/lib/libgammaray_ui-qt6_8-riscv64.so.3.1.0" )

# Import target "gammaray_client" for configuration "Release"
set_property(TARGET gammaray_client APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(gammaray_client PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "gammaray_ui;gammaray_common;Qt6::Gui;Qt6::Widgets;Qt6::Network"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libgammaray_client.so.3.1.0"
  IMPORTED_SONAME_RELEASE "libgammaray_client.so.3.1.0"
  )

list(APPEND _cmake_import_check_targets gammaray_client )
list(APPEND _cmake_import_check_files_for_gammaray_client "${_IMPORT_PREFIX}/lib/libgammaray_client.so.3.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
